@@ -234,54 +234,3 @@ center_limits <- function(around = 0) {
     c(-1, 1) * max(abs(input - around)) + around
   }
 }
-
-# Deprecated --------------------------------------------------------------
-
-#' Passing a subset of data to ggplot2 layers.
-#'
-#' This is a convenience function to allow layer objects, such as geoms, to take
-#' a subset of the data in the main `ggplot()` call, without storing a
-#' duplicate of the subset in the ggplot object.
-#'
-#' @param rowtest logical `expression` indicating which rows to keep.
-#' @param omit a `character` column name to exclude.
-#'
-#' @return A function that takes a `data.frame` as argument and returns a
-#'   subset of that `data.frame` according to `rowtest`
-#' @export
-#'
-#' @details `ggsubset` is a wrapper around `subset.data.frame` where
-#'   the `subset` argument is set to `rowtest` and the `select`
-#'   argument to `-omit`. Since the `data` argument in the
-#'   `layer()` function can take a function with one argument, we can pass
-#'   the function returned from `ggsubset` as that argument to subset the
-#'   data by rows.
-#'
-#' @seealso See [ggplot2::layer()], specifically the `data`
-#'   argument. See [`subset.data.frame()`][base::subset] for the internal
-#'   function.
-#'
-#' @examples
-#' ggplot(iris, aes(Sepal.Width, Sepal.Length)) +
-#'   geom_point(data = ggsubset(Species == "setosa"))
-ggsubset <- function(rowtest = NULL, omit = NULL) {
-  lifecycle::deprecate_warn(
-    "0.2.0",
-    "ggsubset()",
-    details = paste0("This is best replaced by using ",
-                     "`data = ~ subset(.x, ...)` instead.")
-  )
-  rowtest <- substitute(rowtest)
-  if (is.null(rowtest)) {
-    rowtest <- substitute(TRUE)
-  }
-
-  if (!is.null(substitute(omit))) {
-    omit <- substitute(-omit)
-  } else {
-    omit <- TRUE
-  }
-
-  function(x) subset.data.frame(x, eval(rowtest), eval(omit))
-}
-
