@@ -77,7 +77,8 @@ facet_nested_wrap <- function(
   if (isFALSE(nest_line)) {
     nest_line <- element_blank()
   }
-  if (!inherits(nest_line, c("element_line", "element_blank"))) {
+  if (!(is_theme_element(nest_line, "line") ||
+        is_theme_element(nest_line, "blank"))) {
     cli::cli_abort(
       "The {.arg nest_line} argument must be {.cls element_blank} or inherit \\
       from {.cls element_line}."
