@@ -15,7 +15,6 @@ basic <- ggplot(df)
 
 test_that("facet_nested can be added to a plot", {
   g <- basic + facet_nested()
-  expect_s3_class(g$facet, "gg")
   expect_s3_class(g$facet, "Facet")
   expect_s3_class(g$facet, "FacetGrid")
   expect_s3_class(g$facet, "FacetNested")
@@ -24,11 +23,8 @@ test_that("facet_nested can be added to a plot", {
 test_that("facet_nested can be build", {
   g <- basic + facet_nested(~ nester + Species)
   g <- ggplot_build(g)
-  expect_s3_class(g, "ggplot_built")
-  expect_s3_class(g$layout, "gg")
   expect_s3_class(g$layout, "Layout")
-  expect_s3_class(g$plot, "gg")
-  expect_s3_class(g$plot, "ggplot")
+  expect_true(is_ggplot(g$plot))
 })
 
 test_that("facet_nested can be interpreted as gtable", {
@@ -125,9 +121,9 @@ test_that("facet_nested can nest strips", {
 
 test_that("facet_nested constructor handles nesting lines", {
   f <- facet_nested(~ nester + Species, nest_line = TRUE)
-  expect_s3_class(f$params$nest_line, 'element_line')
+  expect_true(is_theme_element(f$params$nest_line, "line"))
   f <- facet_nested(~ nester + Species, nest_line = FALSE)
-  expect_s3_class(f$params$nest_line, "element_blank")
+  expect_true(is_theme_element(f$params$nest_line), "blank")
   f <- quote(facet_nested(~ nester + Species, nest_line = element_rect()))
   expect_error(eval(f))
 })
